@@ -130,10 +130,17 @@ function(model,region.table,samples,obs,options,numRegions,estimate.table,Nhat.b
 #   First compute variance component due to estimation of detection function parameters. Thus uses the
 #   delta method and produces a v-c matrix if more than one strata
 #
-    vcov = solvecov(model$hessian)$inv
-    vc1.list = DeltaMethod(model$par, dht.deriv, vcov, options$pdelta,
-        model = model, samples = samples, obs = obs, options = options)
-    vc1=vc1.list$variance
+	if(!is.null(model$par))
+	{
+       vcov = solvecov(model$hessian)$inv
+       vc1.list = DeltaMethod(model$par, dht.deriv, vcov, options$pdelta,
+           model = model, samples = samples, obs = obs, options = options)
+       vc1=vc1.list$variance
+   } else
+   {
+	   vc1.list=list(variance=0)
+	   vc1=0
+   }   
 #
 #   Next compute the component due to sampling of both lines and of the detection process itself   
 #   There are 3 different options here:
@@ -297,8 +304,11 @@ function(model,region.table,samples,obs,options,numRegions,estimate.table,Nhat.b
         df=estimate.table$k
         df=sapply(df,compute.df,type=options$ervar)
         df[df<1]=1
-        estimate.table$df = estimate.table$cv^4/((diag(vc1)/estimate.table$Estimate^2)^2/(length(model$fitted) - 
-            length(model$par)) + (diag(vc2)/estimate.table$Estimate^2)^2/df)
+		if(all(vc1==0))
+			estimate.table$df = df
+		else	
+            estimate.table$df = estimate.table$cv^4/((diag(vc1)/estimate.table$Estimate^2)^2/(length(model$fitted) - 
+               length(model$par)) + (diag(vc2)/estimate.table$Estimate^2)^2/df)
 #
 #       Following code added 11/11/04 jll to compute proper satterthwaite
 #       df for total estimate assuming sum of indep region estimates; uses variances
@@ -307,11 +317,14 @@ function(model,region.table,samples,obs,options,numRegions,estimate.table,Nhat.b
         if(numRegions>1)
         {
             df.total=(diag(vc2)[numRegions+1])^2/sum((diag(vc2)^2/df)[1:numRegions])
-            estimate.table$df[numRegions+1] = estimate.table$cv[numRegions+1]^4 /
+			if(all(vc1==0))
+				estimate.table$df[numRegions+1] = df.total	
+			else
+               estimate.table$df[numRegions+1] = estimate.table$cv[numRegions+1]^4 /
                            ((diag(vc1)[numRegions+1]/estimate.table$Estimate[numRegions+1]^2)^2/(length(model$fitted)-length(model$par)) 
                            + (diag(vc2)[numRegions+1]/estimate.table$Estimate[numRegions+1]^2)^2/df.total)
         }
-        estimate.table$df[estimate.table$df < 1] = 1
+        estimate.table$df[estimate.table$df < 1 &estimate.table$df >0] = 1
         cvalue = exp((abs(qt(0.025, estimate.table$df)) * sqrt(log(1 + estimate.table$cv^2))))
     }
     else 
